@@ -16,28 +16,31 @@ def sumdumbfun(x,y): # this is only here to test the package during development
 
 ## RootDir establishes the export and data folder structure
 def RootDir(corename, Formation_names):
-    main_dir = ['CoreData', 'CoreOutput','CoreNeuralModel']
-    sub_dir= ['CoreAttributes', 'CoreXRF','CoreBoxPhotos', 'CoreTubes']    
+    Root_path = os.path.dirname(os.getcwd())
+    
+    main_dir = ['CoreData','CoreOutput']    # make it so CorePyCodes is version controlled
+    CoreData_dir= ['CoreAttributes', 'CoreXRF','CoreBoxPhotos', 'CoreTubes','CoreNeuralModel','CoreBeta']   
         
     for i in range(0, len(main_dir)):
-        dirName = str(main_dir[i])
+        dirName =  str(Root_path + '/' + str(main_dir[i]))
         if not os.path.exists(dirName):
             os.makedirs(dirName)
     		      
     # builds the necessary subdirectory folders
 
-    for i in range(0, len(sub_dir)):
-        dirName =  str(main_dir[0]) + '/' + str(sub_dir[i])
+    for i in range(0, len(CoreData_dir)):
+
+        dirName =  str(Root_path + '/' + main_dir[0]) + '/' + str(CoreData_dir[i])
         if not os.path.exists(dirName):
 		        os.makedirs(dirName)
  
     for i in range(0, len(corename)):
-        dirName =  str(main_dir[1]) + '/' + str(corename)
+        dirName =  str(Root_path + '/' + main_dir[1]) + '/' + str(corename)
         if not os.path.exists(dirName):
 		        os.makedirs(dirName)
 
     for i in range(0, len(Formation_names)):
-        dirName =  str(main_dir[1]) + '/' + str(corename) + '/' + str(Formation_names) 
+        dirName =  str(Root_path + '/' + main_dir[1]) + '/' + str(corename) + '/' + str(Formation_names) 
         if not os.path.exists(dirName):
 		        os.makedirs(dirName)
         return dirName        # this is needed to direct output files
@@ -49,10 +52,11 @@ def movingaverage(interval, moving_avg):
                 
 
 def MakeXRFdf(corename,elements,outlier_multiplier,Depth_model,Formation_names):   # bad form here. need to link better but I don't know how to link below RootDir
-
-    XRF_file = os.path.join(str('./Coredata/CoreXRF/') + corename + '_XRF.csv')
-    LODT5 = pd.read_csv(os.path.join(str('./Coredata/CoreXRF/') + 'T5iLOD_XRF.csv'))
-
+    
+    Root_path = os.path.dirname(os.getcwd())
+    XRF_file = os.path.join( Root_path + '/CoreData/CoreXRF/' + corename + '_XRF.csv')
+    LODT5 = pd.read_csv(os.path.join( Root_path + '/CoreData/CoreXRF/' + 'T5iLOD_XRF.csv'))
+    
     files=glob.glob(XRF_file)
 
     for file in files:
@@ -106,7 +110,6 @@ def Kmeans_cluster(x_new,coredata_no_outliers,Principal_components, clusters,PC1
     coredata_no_outliers['Chemofacies_PCA']=Chemofacies_PCA #makes a new column based on above conditional format
     coredata_no_outliers['PCA1']=x_new[:,PC1] #Adds PCA1 to coredata file for reference
     coredata_no_outliers['PCA2']=x_new[:,PC2] #Adds PCA2 to coredata file for reference
-    #features= np.arange(len(elements))
     return coredata_no_outliers
 
 def Elbow_method(x_new,Principal_components):
@@ -142,23 +145,27 @@ def cropCorebox(cropArea, imageFileName,imageFolder,newFolderPath):
     imgOpen.close()
  
 def ImageDir(corename):
+    Root_path = os.path.dirname(os.getcwd())
+    
     main_dir = ['CoreData']
     sub_dir= ['CoreBoxPhotos','CoreTubes']
 
     for i in range(0, len(main_dir)):
-        dirName =  str(main_dir[i])
+        dirName =  str(Root_path + '/' + str(main_dir[i]))
+
         if not os.path.exists(dirName):
             os.makedirs(dirName)
             
     for i in range(0, len(sub_dir)):
-        dirName = str(main_dir[0]) + '/' + str(sub_dir[i])
+        dirName = str(Root_path + '/' + main_dir[0]) + '/' + str(sub_dir[i])
         if not os.path.exists(dirName):
 		        os.makedirs(dirName)
                 
                 
 def OutputXRF(corename,Formation_names):   # bad form here. need to link better but I don't know how to link below RootDir
-     
-    XRF_file = os.path.join(str('./CoreOutput/') + corename + '/' + Formation_names + '/' + corename + '_' + Formation_names + '.csv')
+    Root_path = os.path.dirname(os.getcwd())
+    dirName= str(Root_path + '/CoreOutput/' + corename + '/' + Formation_names + '/')
+    XRF_file = os.path.join(dirName + corename + '_' + Formation_names + '.csv')
     OutputXRF=pd.read_csv(XRF_file)
     return OutputXRF
 
